pub struct UpgradeProposalData {
pub old_version: Version,
pub new_version: Version,
pub decide_by: ViewNumber,
pub new_version_hash: Vec<u8>,
pub old_version_last_view: ViewNumber,
pub new_version_first_view: ViewNumber,
}Expand description
Data used for a Upgrade vote.
Fields
old_version: VersionThe old version that we are upgrading from.
new_version: VersionThe new version that we are upgrading to.
decide_by: ViewNumberThe last view in which we are allowed to reach a decide on this upgrade. If it is not decided by that view, we discard it.
new_version_hash: Vec<u8>A unique identifier for the specific protocol being voted on.
old_version_last_view: ViewNumberThe last block for which the old version will be in effect.
new_version_first_view: ViewNumberThe first block for which the new version will be in effect.